"""add category priority and due date

Revision ID: 5f42ebcf5b2e
Revises: 4f42ebcf5b2d
Create Date: 2025-05-13

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '5f42ebcf5b2e'
down_revision = '4f42ebcf5b2d'
branch_labels = None
depends_on = None


def upgrade():
    # Create an enum type for priority
    op.execute("CREATE TYPE priority_enum AS ENUM ('low', 'medium', 'high')")
    
    # Add new columns
    op.add_column('todos', sa.Column('category', sa.String(), nullable=True))
    op.add_column('todos', sa.Column('priority', sa.Enum('low', 'medium', 'high', name='priority_enum'), nullable=True))
    op.add_column('todos', sa.Column('due_date', sa.DateTime(timezone=True), nullable=True))
    
    # Create index on category for faster queries
    op.create_index(op.f('ix_todos_category'), 'todos', ['category'], unique=False)

    # Set default values
    op.execute("UPDATE todos SET priority = 'medium' WHERE priority IS NULL")


def downgrade():
    # Drop index
    op.drop_index(op.f('ix_todos_category'), table_name='todos')
    
    # Drop columns
    op.drop_column('todos', 'due_date')
    op.drop_column('todos', 'priority')
    op.drop_column('todos', 'category')
    
    # Drop enum type
    op.execute("DROP TYPE priority_enum")